@@ -1,10 +1,11 @@
 import logging
 import warnings
 
-from django.utils.cache import patch_vary_headers
+from esteid_certificates import get_certificate_file_name
+
+from esteid import settings
+from esteid.util import parse_legacy_dn, parse_rfc_dn
 
-from esteid.helpers import parse_legacy_dn, parse_rfc_dn
-from . import config
 from .ocsp import OCSPVerifier
 
 
@@ -22,28 +23,8 @@ ERROR_NO_DN = 3000
 ERROR_INVALID_DN = 3001
 
 
-class MultiHostMiddleware(MiddlewareMixin):
-    def process_request(self, request):
-        # Choose which subhost to use (if any):
-        host = request.META["HTTP_HOST"]
-        if host[-3:] == ":80":
-            host = host[:-3]  # ignore default port number, if present
-
-        request.subhost_name = 'default'
-        for host_name, host_config in config.get_hosts().items():
-            if host.startswith(host_name) or host == host_config.get('hostname'):
-                request.subhost_name = host_name
-                request.urlconf = host_config.get('urlconf')
-
-    def process_response(self, request, response):
-        if getattr(request, "urlconf", None):
-            patch_vary_headers(response, ('Host',))
-
-        return response
-
-
 class BaseIdCardMiddleware(MiddlewareMixin):
-    """ Base class for receiving authentication info from ID card.
+    """Base class for receiving authentication info from ID card.
 
     Note that this requires cooperation from the web server (eg Apache / Nginx) - the server must request client
     certificate and pass it on in specific HTTP headers.
@@ -62,6 +43,9 @@ class BaseIdCardMiddleware(MiddlewareMixin):
     - `SN` - last name (surname), e.g. 'SMITH'
 
     If authentication fails, the request will have `id_err` attribute with value of the error code.
+
+    Documentation (In Estonian):
+    https://eid.eesti.ee/index.php/Kasutaja_tuvastamine_veebis#Veebiserveri_konfigureerimine
     """
 
     DN_HEADER_NAME = None
@@ -70,11 +54,11 @@ class BaseIdCardMiddleware(MiddlewareMixin):
 
     # If any of these is not present in client DN, the authentication fails
     REQUIRED_DN_FIELDS = {
-        'serialNumber',
-        'C',
-        'CN',
-        'GN',
-        'SN',
+        "serialNumber",
+        "C",
+        "CN",
+        "GN",
+        "SN",
     }
 
     def process_request(self, request):
@@ -83,23 +67,23 @@ class BaseIdCardMiddleware(MiddlewareMixin):
         # Get the subject DN from header
         client_dn = request.META.get(self.DN_HEADER_NAME, None)
         if client_dn is None:
-            setattr(request, 'id_err', ERROR_NO_DN)
+            setattr(request, "id_err", ERROR_NO_DN)
             return
 
         id_auth = self.parse_client_dn(client_dn)
         if not self.REQUIRED_DN_FIELDS.issubset(id_auth.keys()):
             logger.info("BaseIdCardMiddleware: required DN fields missing, client DN is %s", client_dn)
-            setattr(request, 'id_err', ERROR_INVALID_DN)
+            setattr(request, "id_err", ERROR_INVALID_DN)
             return
 
-        setattr(request, 'id_auth', id_auth)
+        setattr(request, "id_auth", id_auth)
 
         if self.CERTIFICATE_HEADER_NAME is not None and self.ISSUER_HEADER_NAME is not None:
             issuer = request.META.get(self.ISSUER_HEADER_NAME, None)
             certificate = request.META.get(self.CERTIFICATE_HEADER_NAME, None)
             if issuer and certificate:
                 certificate = self.prepare_certificate(certificate)
-                setattr(request, 'id_cert', certificate)
+                setattr(request, "id_cert", certificate)
 
                 # OCSP check
                 issuer = self.parse_client_dn(issuer)
@@ -108,9 +92,9 @@ class BaseIdCardMiddleware(MiddlewareMixin):
                 # Code 0 means success, everything else is error
                 if response != 0:
                     logger.info("BaseIdCardMiddleware: OCSP verification returned %s", response)
-                    delattr(request, 'id_auth')
+                    delattr(request, "id_auth")
                     # Pad OCSP error codes with 4000
-                    setattr(request, 'id_err', 4000 + response)
+                    setattr(request, "id_err", 4000 + response)
 
     def prepare_certificate(self, certificate):
         """ Use this in case the certificate value in HTTP header needs formatting. """
@@ -128,7 +112,7 @@ class BaseIdCardMiddleware(MiddlewareMixin):
 
         :return:str
         """
-        return config.ocsp_url()
+        return settings.OCSP_URL
 
     @classmethod
     def get_ocsp_responder_certificate_path(cls):
@@ -138,42 +122,48 @@ class BaseIdCardMiddleware(MiddlewareMixin):
 
         :return:str
         """
-        return config.ocsp_responder_certificate_path()
+        certificate_path = getattr(settings, "ESTEID_OCSP_RESPONDER_CERTIFICATE_PATH", None)
+        test_cert_name = "TEST of SK OCSP RESPONDER 2011"
+        live_cert_name = "sk-ocsp-responder-certificates"
+        # Preserve compatibility
+        if certificate_path == "TEST_of_SK_OCSP_RESPONDER_2011.pem":
+            return get_certificate_file_name(test_cert_name)
+        if certificate_path == "sk-ocsp-responder-certificates.pem":
+            return get_certificate_file_name(live_cert_name)
+
+        return test_cert_name if settings.ESTEID_DEMO else live_cert_name
 
     @classmethod
     def verify_ocsp(cls, certificate, issuer):
-        """ Runs OCSP verification and returns error code - 0 means success
-        """
+        """Runs OCSP verification and returns error code - 0 means success"""
 
-        return OCSPVerifier(certificate, issuer,
-                            cls.get_ocsp_url(),
-                            cls.get_ocsp_responder_certificate_path()).verify()
+        return OCSPVerifier(certificate, issuer, cls.get_ocsp_url(), cls.get_ocsp_responder_certificate_path()).verify()
 
 
 class ApacheIdCardMiddleware(BaseIdCardMiddleware):
-    """ ID card middleware configured for Apache server
+    """ID card middleware configured for Apache server
 
     Requires standard SSL_CLIENT_S_DN, SSL_CLIENT_I_DN and SSL_CLIENT_CERT headers.
     """
 
-    DN_HEADER_NAME = 'HTTP_SSL_CLIENT_S_DN'
-    ISSUER_HEADER_NAME = 'HTTP_SSL_CLIENT_I_DN'
-    CERTIFICATE_HEADER_NAME = 'HTTP_SSL_CLIENT_CERT'
+    DN_HEADER_NAME = "HTTP_SSL_CLIENT_S_DN"
+    ISSUER_HEADER_NAME = "HTTP_SSL_CLIENT_I_DN"
+    CERTIFICATE_HEADER_NAME = "HTTP_SSL_CLIENT_CERT"
 
     def prepare_certificate(self, certificate):
-        return certificate.replace(' ', '\n').replace('\nCERTIFICATE-----', ' CERTIFICATE-----')
+        return certificate.replace(" ", "\n").replace("\nCERTIFICATE-----", " CERTIFICATE-----")
 
     def parse_client_dn(self, dn):
         return parse_rfc_dn(dn)
 
 
 class NginxIdCardMiddleware(BaseIdCardMiddleware):
-    """ ID card middleware configured for Nginx server
+    """ID card middleware configured for Nginx server
 
     Note that Nginx middleware does NOT perform validation (OCSP) checks for the received certificate.
     """
 
-    DN_HEADER_NAME = 'HTTP_X_CLIENT'
+    DN_HEADER_NAME = "HTTP_X_CLIENT"
 
 
 class IdCardMiddleware(NginxIdCardMiddleware):
@@ -182,6 +172,7 @@ class IdCardMiddleware(NginxIdCardMiddleware):
     def __init__(self, *args, **kwargs):
         warnings.warn(
             "IdCardMiddleware is deprecated - use ApacheIdCardMiddleware or NginxIdCardMiddleware",
-            DeprecationWarning, stacklevel=2
+            DeprecationWarning,
+            stacklevel=2,
         )
         super().__init__(*args, **kwargs)
